@@ -3,13 +3,13 @@ function (age, waitsp, waitext, complete=TRUE, tiplabel, shiftsp, shiftext, samp
 { 
   # create waiting time functions #
   if (is.function(waitsp)){
-    rnumbsp <- parse(text="waitsp()")
+    rnumbsp <- waitsp#parse(text="waitsp()")
   } else if (is.character(waitsp)){
     rnumbsp <- express.distribution(waitsp)
   }
   
   if (is.function(waitext)){
-    rnumbext <- parse(text="waitext()")
+    rnumbext <- waitext#parse(text="waitext()")
     firstextpar <- "funk"
   } else if (is.character(waitext)){
     rnumbext <- express.distribution(waitext)
@@ -17,13 +17,13 @@ function (age, waitsp, waitext, complete=TRUE, tiplabel, shiftsp, shiftext, samp
   }
   
   if (is.function(shiftsp$strength)){
-    rnumbshiftsp <- parse(text="shiftsp$strength()")
+    rnumbshiftsp <- shiftsp$strength#parse(text="shiftsp$strength()")
   } else if (is.character(shiftsp$strength)){
     rnumbshiftsp <- express.distribution(shiftsp$strength)
   }
   
   if (is.function(shiftext$strength)){
-    rnumbshiftext <- parse(text="shiftext$strength()")
+    rnumbshiftext <- shiftext$strength#parse(text="shiftext$strength()")
   } else if (is.character(shiftext$strength)){
     rnumbshiftext <- express.distribution(shiftext$strength)
   }
@@ -43,7 +43,7 @@ function (age, waitsp, waitext, complete=TRUE, tiplabel, shiftsp, shiftext, samp
   testshiftsp <- function (spt){
     if (shiftspprob!=0){
       if (runif(1,0,1)<shiftspprob) { #cheking if shift happens based on a uniform distribution U[0,1]
-        shiftspstrength <- eval(rnumbshiftsp) #draw shift strength
+        shiftspstrength <- rnumbshiftsp()#eval(rnumbshiftsp) #draw shift strength
         #print(paste("Hey, a speciation shift happened at node", nextsp - i, "with strenght", shiftspstrength ))
       }else{
         shiftspstrength <- shiftspm[shiftspm[,"node"]==species,"strength"] #inherit ancestor shift
@@ -63,7 +63,7 @@ function (age, waitsp, waitext, complete=TRUE, tiplabel, shiftsp, shiftext, samp
   testshiftext <- function (extt){
     if (shiftextprob!=0){
       if (runif(1,0,1)<shiftextprob) { #cheking if shift happens based on a uniform distribution U[0,1]
-        shiftextstrength <- eval(rnumbshiftext) #draw shift strength
+        shiftextstrength <- rnumbshiftext()#eval(rnumbshiftext) #draw shift strength
         #print(paste("Hey, an extinction shift happened at node", nextsp - i, "with strenght", shiftextstrength ))
       }else{
         shiftextstrength <- shiftextm[shiftextm[,"node"]==species,"strength"] #inherit ancestor shift
@@ -128,16 +128,16 @@ function (age, waitsp, waitext, complete=TRUE, tiplabel, shiftsp, shiftext, samp
   ##SM-E
   
   # initial if in case the (-1,-2) edge get extinct or bigger than age
-  spt <- eval(rnumbsp)
+  spt <- rnumbsp()#eval(rnumbsp)
   #to remove NaN warnings messages in case of zero inside the distribution parameters
   {
   if (firstextpar == 0)
   {
-    extt <- suppressWarnings(eval(rnumbext))
+    extt <- suppressWarnings(rnumbext())#eval(rnumbext)
   }
   else
   {
-    extt <- eval(rnumbext)
+    extt <- rnumbext()#eval(rnumbext)
   }
   }
   {
@@ -195,7 +195,7 @@ function (age, waitsp, waitext, complete=TRUE, tiplabel, shiftsp, shiftext, samp
     i <- 1
     edge <- rbind( edge, c(species, (nextsp - i)))
     motherage <- sum(    trajectoryuntil(   godbook$to[which(godbook$to == species)]  ,    godbook$from[which(godbook$to == species)]))
-    spt <- eval(rnumbsp)
+    spt <- rnumbsp()#eval(rnumbsp)
     #SM-S
     testshiftspout <- testshiftsp(spt)
     spt <- testshiftspout$spt
@@ -207,13 +207,13 @@ function (age, waitsp, waitext, complete=TRUE, tiplabel, shiftsp, shiftext, samp
     count <- 0
     while (spt <= motherage) {
       # print(paste("again.. because spt was=", spt))
-      spt <- eval(rnumbsp)
+      spt <- rnumbsp()#eval(rnumbsp)
       #SM-S
       testshiftspout <- testshiftsp(spt)
       spt <- testshiftspout$spt
       count <- count+1
       if (count>10 & spt==motherage) {
-        spt <- eval(rnumbext) +1
+        spt <- rnumbext() +1
         break()
       }
       ##SM -E
@@ -268,7 +268,7 @@ function (age, waitsp, waitext, complete=TRUE, tiplabel, shiftsp, shiftext, samp
     #for the child birth
     i <- 2
     edge <- rbind( edge, c(species, (nextsp - i)))
-    spt <- eval(rnumbsp)
+    spt <- rnumbsp()#eval(rnumbsp)
     ##SM -S now we examine for shifts and update spt and shiftspm
     testshiftspout <- testshiftsp(spt)
     spt <- testshiftspout$spt
@@ -278,11 +278,11 @@ function (age, waitsp, waitext, complete=TRUE, tiplabel, shiftsp, shiftext, samp
     {
     if (firstextpar == 0)
     {
-      extt <- suppressWarnings(eval(rnumbext))
+      extt <- suppressWarnings(rnumbext())#eval(rnumbext)
     }
     else
     {
-      extt <- eval(rnumbext)
+      extt <- rnumbext()#eval(rnumbext)
     }
     }
     # if to see if the user simulates with extinction = ZERO and avoid error generated by expression-distribution when rate equals zero
