@@ -4,13 +4,13 @@ function (m, waitsp, waitext, complete=TRUE, tiplabel, shiftsp, shiftext, sampli
 
   # create waiting time functions #
   if (is.function(waitsp)){
-    rnumbsp <- parse(text="waitsp()")
+    rnumbsp <- waitsp#parse(text="waitsp()")
   } else if (is.character(waitsp)){
     rnumbsp <- express.distribution(waitsp)
   }
   
   if (is.function(waitext)){
-    rnumbext <- parse(text="waitext()")
+    rnumbext <- waitext#parse(text="waitext()")
     firstextpar <- "funk"
   } else if (is.character(waitext)){
     rnumbext <- express.distribution(waitext)
@@ -18,13 +18,13 @@ function (m, waitsp, waitext, complete=TRUE, tiplabel, shiftsp, shiftext, sampli
   }
   
   if (is.function(shiftsp$strength)){
-    rnumbshiftsp <- parse(text="shiftsp$strength()")
+    rnumbshiftsp <- shiftsp$strength#parse(text="shiftsp$strength()")
   } else if (is.character(shiftsp$strength)){
     rnumbshiftsp <- express.distribution(shiftsp$strength)
   }
   
   if (is.function(shiftext$strength)){
-    rnumbshiftext <- parse(text="shiftext$strength()")
+    rnumbshiftext <- shiftext$strength#parse(text="shiftext$strength()")
   } else if (is.character(shiftext$strength)){
     rnumbshiftext <- express.distribution(shiftext$strength)
   }
@@ -45,7 +45,7 @@ function (m, waitsp, waitext, complete=TRUE, tiplabel, shiftsp, shiftext, sampli
 testshiftsp <- function (spt){
   if (shiftspprob!=0){
     if (runif(1,0,1)<shiftspprob) { #cheking if shift happens based on a uniform distribution U[0,1]
-      shiftspstrength <- eval(rnumbshiftsp) #draw shift strength
+      shiftspstrength <- rnumbshiftsp() #draw shift strength
       #print(paste("Hey, a speciation shift happened at node", nextsp - i, "with strenght", shiftspstrength ))
     }else{
       shiftspstrength <- shiftspm[shiftspm[,"node"]==species,"strength"] #inherit ancestor shift
@@ -66,7 +66,7 @@ testshiftsp <- function (spt){
 testshiftext <- function (extt){
   if (shiftextprob!=0){
     if (runif(1,0,1)<shiftextprob) { #cheking if shift happens based on a uniform distribution U[0,1]
-      shiftextstrength <- eval(rnumbshiftext) #draw shift strength
+      shiftextstrength <- rnumbshiftext() #draw shift strength
       #print(paste("Hey, an extinction shift happened at node", nextsp - i, "with strenght", shiftextstrength ))
     }else{
       shiftextstrength <- shiftextm[shiftextm[,"node"]==species,"strength"] #inherit ancestor shift
@@ -137,16 +137,16 @@ while (bingo == FALSE)	# while bingo start
 	timeline <- NULL
 
 # initial if in case the (-1,-2) edge get extinct or bigger than age
-spt <- eval(rnumbsp)
+spt <- rnumbsp()
 #to remove NaN warnings messages
 {
 if (firstextpar == 0)
 {
-	extt <- suppressWarnings(eval(rnumbext))
+	extt <- suppressWarnings(rnumbext())
 }
 else
 {
-	extt <- eval(rnumbext)
+	extt <- rnumbext()
 }
 }
 # if to see if the user simulates with extinction = ZERO and avoid error generated by exp. distribution when rate equals zero
@@ -191,7 +191,7 @@ while (stop == FALSE)
 	#for the mother to prolong
 	i <- 1
 	edge <- rbind( edge, c(species, (nextsp - i)))
-	spt <- eval(rnumbsp)
+	spt <- rnumbsp()
 	##SM -S now we examine for shifts and update spt and shiftspm
 	testshiftspout <- testshiftsp(spt)
 	spt <- testshiftspout$spt
@@ -203,7 +203,7 @@ while (stop == FALSE)
 	##
 	while (spt <= godbook$age[positiongodbook]){
 		#print(paste("again.. because spt was=", spt))
-		spt <- eval(rnumbsp)
+		spt <- rnumbsp()
 		##SM - S now we examine for shifts and update spt and shiftspm
 		testshiftspout <- testshiftsp(spt)
 		spt <- testshiftspout$spt
@@ -250,7 +250,7 @@ while (stop == FALSE)
 	#for the daughter lineage birth
 	i <- 2
 	edge <- rbind( edge, c(species, (nextsp - i)))
-	spt <- eval(rnumbsp)
+	spt <- rnumbsp()
 	##SM -S now we examine for shifts and update spt and shiftspm
 	testshiftspout <- testshiftsp(spt)
 	spt <- testshiftspout$spt
@@ -260,11 +260,11 @@ while (stop == FALSE)
 	{
 	if (firstextpar == 0)
 	{
-		extt <- suppressWarnings(eval(rnumbext))
+		extt <- suppressWarnings(rnumbext())
 	}
 	else
 	{
-		extt <- eval(rnumbext)
+		extt <- rnumbext()
 	}
 	}
 	# if to see if the user simulates with extinction = ZERO and avoid error generated by exp. distribution when rate equals zero
